@@ -14,7 +14,7 @@ from ..manifold import basic_manifold, complex_basic_manifold
 # from autograd.numpy.linalg import solve, pinv
 
 class basic_manifold_torch(basic_manifold):
-    def __init__(self,name: str,variable_shape: Tuple[int], constraint_shape: Tuple[int], device = torch.device('cpu'), dtype = torch.float64,  regularize_value = 0.01, safegurad_value = 0) -> None:
+    def __init__(self,name: str,variable_shape: Tuple[int], constraint_shape: Tuple[int], device = torch.device('cpu'), dtype = torch.float64,  regularize_value = 0.01, safeguard_value = 0) -> None:
         self.name = name
         self.shape = (variable_shape,) 
         self.var_shape = variable_shape
@@ -22,7 +22,7 @@ class basic_manifold_torch(basic_manifold):
         self.device = device
         self.dtype = dtype
         self.regularize_value = regularize_value
-        self.safegurad_value = safegurad_value
+        self.safeguard_value = safeguard_value
 
         self._parameters = OrderedDict()
 
@@ -34,7 +34,7 @@ class basic_manifold_torch(basic_manifold):
         # self.Ip = torch.eye()
 
         
-        super().__init__(self.name,self.var_shape, self.con_shape,  backbone = 'torch',regularize_value = self.regularize_value, safegurad_value = self.safegurad_value, device= self.device ,dtype= self.dtype)
+        super().__init__(self.name,self.var_shape, self.con_shape,  backbone = 'torch',regularize_value = self.regularize_value, safeguard_value = self.safeguard_value, device= self.device ,dtype= self.dtype)
 
         
     
